/*
	extraset-kn2.cpp
	Solution to "Extraset"
	SIUCF CompProg Camp 2018, Contest 2

	This code is runs in the intended complexity of
	O(n^2k). However, an O(n^3/6) solution exists that
	performs better.

	solution by Charles B.

	9 July 2018
*/
#include <bits/stdc++.h>

typedef long long ll;

struct Trie {
	const static ll ALPHA = 3;
	const static char ALPHA_BEG = '0';

	struct TrieNode {
		ll count;

		std::vector<TrieNode*> next;

		TrieNode(const char& val, TrieNode* p = nullptr) {
			count = 0;
			next.assign(ALPHA, nullptr);
		}

		~TrieNode(void) {
			for (auto& e : next)
				if (e != nullptr)
					delete e;
		}
	};

	TrieNode* root;

	Trie(void) {
		root = new TrieNode('$', nullptr);
	}

	~Trie(void) {
		delete root;
	}

	void insert(const std::string& s, const ll& num) {
		TrieNode* curr = this->root;

		for (ll i = 0; i < static_cast<ll>(s.length()); ++i) {
			ll tmp = std::tolower(s[i]) - ALPHA_BEG;
			if (curr->next[tmp] == nullptr)
				curr->next[tmp] = new TrieNode(tmp + ALPHA_BEG, curr);
			curr = curr->next[tmp];
		}

		curr->count = num;
	}

	TrieNode* find_end(const std::string& s) const {
		TrieNode* curr = this->root;

		for (ll i = 0; i < static_cast<ll>(s.length()); ++i) {
			ll tmp = std::tolower(s[i]) - ALPHA_BEG;
			if (curr->next[tmp] == nullptr)
				return nullptr;
			curr = curr->next[tmp];
		}

		return curr;
	}

	ll count(const std::string& s) const {
		TrieNode* ret = find_end(s);
		return ret == nullptr ? 0 : ret->count;
	}

	bool find(const std::string& s) const {
		return count(s) > 0;
	}
};

static inline void setio(void);

const ll MAX_K = 20, MAX_N = 1501;

std::string hack[MAX_N];

int main(void) {
	setio();

	Trie tr;

	ll k, n; std::cin >> k >> n;
	std::cin.ignore();
	for (ll i = 0; i < n; ++i) {
		std::getline(std::cin, hack[i]);
		auto it = std::remove_if(hack[i].begin(), hack[i].end(), ::isspace);
		hack[i].erase(it, hack[i].end());
		if (tr.find(hack[i])) {
			std::cerr << "DUP\n";
		}
		tr.insert(hack[i], i + 1);
	}

	ll tot = 0;

	for (ll i = 0; i < n; ++i) {
		for (ll j = i+1; j < n; ++j) {
			std::string tmp;
			for (ll x = 0; x < k; ++x) {
				if (hack[i][x] == hack[j][x]) {
					tmp += hack[i][x];
				} else {
					std::string hi = "012";
					std::remove_if(hi.begin(), hi.end(), [&](const char& c){
						return hack[i][x] == c || hack[j][x] == c;
					});
					tmp += hi.front();
				}
			}

			tot += (tr.count(tmp) > j+1);
		}
	}

	std::cout << tot << "\n";

	std::cerr << static_cast<double>(clock())/CLOCKS_PER_SEC << "\n";

	return 0;
}

static inline void setio(void) {
	std::ios::sync_with_stdio(false);std::cin.tie(nullptr);
	std::cout.precision(10); std::cout << std::fixed;
}
