/*
	moreicecream.cpp
	Solution to "More Ice Cream for Anya"
	SIUCF CompProg Camp 2018, Contest 2

	problem and solution by Charles B.

	29 Jun 2018
*/
#include <bits/stdc++.h>

#define FI first
#define SE second

typedef long long ll;
typedef std::pair<ll,ll> pairll;

template <class T, class Compare>
struct SegmentTree {

	const ll n;
	const Compare CMP; /* used for compares to avoid lots of object creation */
	const T LEAST_EXTREME;

	T *delta, *min;

	SegmentTree(const ll& _n, const T& le) : n(_n), CMP(), LEAST_EXTREME(le) {
		delta = new T[4 * n + 1]();
		min   = new T[4 * n + 1]();
	}

	~SegmentTree(void) {delete [] delta; delete [] min;}

	void prop(const ll& idx) {
		if (delta[idx] == T()) return ;
		set(2 * idx + 1, delta[idx]);
		set(2 * idx + 2, delta[idx]);
		delta[idx] = T();
	}

	void set(const ll& idx, const T& value) {
		delta[idx] = min[idx] = value;
	}

	void update(const ll& left, const ll& right, const T& val) {
		update(0, 0, n-1, left, right, val);
	}

	void update(const ll& i, const ll& lr, const ll& rr, const ll& left, const ll& right, const T& val) {
		if (lr == left && rr == right) {
			set(i, val);
		} else {
			prop(i);
			const ll mid = (lr + rr) / 2;
			if (left <= mid)
				update(2 * i + 1, lr, mid, left, std::min(mid, right), val);
			if (mid < right)
				update(2 * i + 2, mid + 1, rr, std::max(mid+1, left), right, val);
			min[i] = std::min(min[2 * i + 1], min[2 * i + 2], CMP);
		}
	}

	T query(const ll& left, const ll& right) {
		return query(0, 0, n-1, left, right);
	}

	T query(const ll& i, const ll& lr, const ll& rr, const ll& left, const ll& right) {
		if (lr == left && rr == right) return min[i];

		prop(i);
		const ll mid = (lr + rr) / 2;
		T ret = LEAST_EXTREME;
		if (left <= mid) {
			T tmp = query(2 * i + 1, lr, mid, left, std::min(mid, right));
			ret = std::min(ret, tmp, CMP);
		}
		if (mid < right) {
			T tmp = query(2 * i + 2, mid + 1, rr, std::max(mid+1, left), right);
			ret = std::min(ret, tmp, CMP);
		}
		return ret;
	}
};

struct MyComp {
	bool operator()(const ll& a, const ll& b) const {
		const ll bits_a = __builtin_popcountll(a), bits_b = __builtin_popcountll(b);
		return bits_a > bits_b || (bits_a == bits_b && a > b);
	}
};

static inline void setio(void);

const ll MAX_N = 100001;

ll vals[MAX_N], pre[MAX_N], skip[MAX_N];

std::vector<ll> graph[MAX_N];

int main(void) {
	setio();

	ll n, q; std::cin >> n >> q;

	for (ll i = 0; i < n; ++i) {
		std::cin >> vals[i];
	}

	for (ll i = 1, p; i < n; ++i) {
		std::cin >> p;
		graph[p-1].push_back(i);
	}

	/* label preorder/skip iterative dfs. */
	ll po = 0;
	std::stack<pairll> stk;
	stk.push({0,0});

	while (!stk.empty() ){
		pairll now = stk.top();
		stk.pop();

		if (now.SE == 0) {
			pre[now.FI] = po++;
		}

		if (now.SE < static_cast<ll>(graph[now.FI].size())) {
			stk.push({now.FI, now.SE + 1});
			stk.push({graph[now.FI][now.SE], 0});
		} else {
			skip[now.FI] = po;
		}
	}

	/* constructor takes n, size of tree, and the second argument
	is the "least extreme value", as you would INT_MIN when maxing stuff. */
	SegmentTree<ll, MyComp> tree(n, 0);
	for (ll i = 0; i < n; ++i) {
		tree.update(pre[i], pre[i], vals[i]);
	}

	for (ll t, r; q--; ) {
		std::cin >> t >> r; --r;
		if (t == 1) {
			std::cout << tree.query(pre[r], skip[r]-1) << "\n";
		} else {
			std::cin >> vals[r];
			tree.update(pre[r], pre[r], vals[r]);
		}
	}

	std::cerr << std::setprecision(6) << static_cast<double>(clock())/CLOCKS_PER_SEC << "\n";

	return 0;
}

static inline void setio(void) {
	std::ios::sync_with_stdio(false);std::cin.tie(nullptr);
	std::cout.precision(10); std::cout << std::fixed;
}
