import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.InputMismatchException;

public class plinko_jacob implements Runnable {

	public static void main(String[] args) throws IOException {
		new Thread(null, new plinko_jacob(), "name", (1L << 30)).start();
	}

	static class Solver {

		int R, C, K;
		int[][] dir, val;
		int[][][] memo;

		// if the ball is currently at location [r][c], and we can still move k dials,
		// what is the best total we can achieve?
		int dp(int r, int c, int k) {
			// we are out of bounds, or we're trying to move onto a block
			if (r < 0 || c < 0 || r == R || c == C || dir[r][c] == -2)
				return 0;
			// we've already computed this answer
			if (memo[r][c][k] != -1)
				return memo[r][c][k];
			// this is what we'll get without changing the dial
			int best = dp(r + 1, c + dir[r][c], k);
			// if we have moves left, try shifting dial to the other directions
			if (k != 0)
				for (int i = -1; i <= 1; i++)
					if (i != dir[r][c])
						best = Math.max(best, dp(r + 1, c + i, k - 1));
			// save our answer - it's this cell's value plus the best answer we found after
			// trying to shift the dial
			return memo[r][c][k] = val[r][c] + best;

		}

		void solve(FastScanner s, PrintWriter out) {
			R = s.nextInt();
			C = s.nextInt();
			K = s.nextInt();
			dir = new int[R][C];
			val = new int[R][C];
			memo = new int[R][C][K + 1];

			// -2: #
			// -1: /
			// 0: |
			// 1: \

			for (int r = 0; r < R; r++) {
				char[] row = s.next().toCharArray();
				for (int c = 0; c < C; c++) {
					if (row[c] == '#')
						dir[r][c] = -2;
					else if (row[c] == '/')
						dir[r][c] = -1;
					else if (row[c] == '\\')
						dir[r][c] = 1;
				}
			}

			for (int r = 0; r < R; r++)
				for (int c = 0; c < C; c++)
					val[r][c] = s.nextInt();

			for (int[][] a : memo)
				for (int[] b : a)
					Arrays.fill(b, -1);

			// we try placing the ball into every available dial
			int best = 0;
			for (int r = 0; r < R; r++)
				for (int c = 0; c < C; c++)
					best = Math.max(best, dp(r, c, K));

			out.println(best);

		}

	}

	public void run() {

		FastScanner s = new FastScanner(System.in);
		PrintWriter out = new PrintWriter(System.out);

		Solver solver = new Solver();
		solver.solve(s, out);

		out.close();

	}

	static class FastScanner {
		private InputStream stream;
		private byte[] buf = new byte[1024];
		private int curChar;
		private int numChars;

		public FastScanner(InputStream stream) {
			this.stream = stream;
		}

		public FastScanner(String s) throws FileNotFoundException {
			this(new FileInputStream(new File(s)));
		}

		public FastScanner(String s, boolean v) {
			this.stream = new ByteArrayInputStream(s.getBytes(StandardCharsets.UTF_8));
		}

		int read() {
			if (numChars == -1)
				throw new InputMismatchException();
			if (curChar >= numChars) {
				curChar = 0;
				try {
					numChars = stream.read(buf);
				} catch (IOException e) {
					throw new InputMismatchException();
				}
				if (numChars <= 0)
					return -1;
			}
			return buf[curChar++];
		}

		boolean isSpaceChar(int c) {
			return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
		}

		boolean isEndline(int c) {
			return c == '\n' || c == '\r' || c == -1;
		}

		public int nextInt() {
			return Integer.parseInt(next());
		}

		public long nextLong() {
			return Long.parseLong(next());
		}

		public double nextDouble() {
			return Double.parseDouble(next());
		}

		public String next() {
			int c = read();
			while (isSpaceChar(c))
				c = read();
			StringBuilder res = new StringBuilder();
			do {
				res.appendCodePoint(c);
				c = read();
			} while (!isSpaceChar(c));
			return res.toString();
		}

		public String nextLine() {
			int c = read();
			while (isEndline(c))
				c = read();
			StringBuilder res = new StringBuilder();
			do {
				res.appendCodePoint(c);
				c = read();
			} while (!isEndline(c));
			return res.toString();
		}

		// Jacob Garbage

		public int[] nextIntArray(int N) {
			int[] ret = new int[N];
			for (int i = 0; i < N; i++)
				ret[i] = this.nextInt();
			return ret;
		}

		public long[] nextLongArray(int N) {
			long[] ret = new long[N];
			for (int i = 0; i < N; i++)
				ret[i] = this.nextLong();
			return ret;
		}

		public int[][] next2DIntArray(int N, int M) {
			int[][] ret = new int[N][];
			for (int i = 0; i < N; i++)
				ret[i] = this.nextIntArray(M);
			return ret;
		}

		public double[] nextDoubleArray(int N) {
			double[] ret = new double[N];
			for (int i = 0; i < N; i++)
				ret[i] = this.nextDouble();
			return ret;
		}

		public double[][] next2DDoubleArray(int N, int M) {
			double[][] ret = new double[N][];
			for (int i = 0; i < N; i++)
				ret[i] = this.nextDoubleArray(M);
			return ret;
		}

	}

}
